@@ -62,11 +62,8 @@ class DataClient:
                     "end_date": datetime.strftime(date_split[index+1], "%Y%m%d%H%M%S"),
                 }
                 key = json.dumps(args, sort_keys=True)
-                if sys.platform == "darwin":
-                    cache_client = {}
-                else:
-                    cache_file = os.path.join(gettempdir(), key)
-                    cache_client = shelve.open(cache_file, writeback=True)
+                cache_file = os.path.join(gettempdir(), key)
+                cache_client = shelve.open(cache_file, writeback=True)
                 try:
                     if use_cache:
                         if key in cache_client:
